@@ -1,5 +1,4 @@
 /* eslint no-redeclare: "off" */
-/* eslint no-unused-vars: "off" */
 
 function removeComment(form, callback) {
   let parameters = Nitrate.Utils.formSerialize(form);
@@ -30,12 +29,12 @@ function submitComment(container, parameters, callback) {
 /**
  * Update comments count by increasing or decreasing the number.
  *
- * @param {string} caseId - the case id used to select specific elements to be updated.
+ * @param {number} caseId - the case id used to select specific elements to be updated.
  * @param {boolean} increase - increase or decrease the number.
  */
 function updateCommentsCount(caseId, increase) {
-  let commentDiv = jQ('#' + caseId + '_case_comment_count');
-  let countText = jQ('#' + caseId + '_comments_count');
+  let commentDiv = jQ('#' + caseId.toString() + '_case_comment_count');
+  let countText = jQ('#' + caseId.toString() + '_comments_count');
   if (increase) {
     if (commentDiv.children().length === 1) {
       commentDiv.prepend('<img src="/static/images/comment.png" style="vertical-align: middle;">');
@@ -43,7 +42,7 @@ function updateCommentsCount(caseId, increase) {
     countText.text(' ' + (parseInt(countText.text()) + 1));
   } else {
     if (parseInt(countText.text(), 10) === 1) {
-      commentDiv.html('<span id="' + caseId + '_comments_count"> 0</span>');
+      commentDiv.html('<span id="' + caseId.toString() + '_comments_count"> 0</span>');
     } else {
       countText.text(' ' + (parseInt(commentDiv.text()) - 1));
     }
