@@ -117,7 +117,7 @@ Nitrate.TestPlans.TreeView = {
       url: '/plan/' + planId + '/treeview/',
       container: treeViewContainer,
       callbackAfterFillIn: function (xhr) {
-        let planPK = parseInt(jQ('#id_tree_container').data('param'));
+        let planPK = parseInt(document.getElementById('id_tree_container').dataset.planId);
 
         jQ('#js-change-parent-node').on('click', function () {
           thisView.changeParentPlan(planPK);
@@ -344,7 +344,7 @@ Nitrate.TestPlans.Edit.on_load = function () {
   });
 
   jQ('.js-back-button').on('click', function () {
-    window.location.href = jQ(this).data('param');
+    window.location.assign(this.dataset.actionUrl);
   });
 };
 
@@ -354,25 +354,11 @@ Nitrate.TestPlans.Edit.on_load = function () {
  */
 function bindSearchResultActionEventHandlers() {
   jQ('.js-new-plan').on('click', function () {
-    window.location = jQ(this).data('param');
+    window.location.assign(this.dataset.actionUrl);
   });
-  jQ('.js-clone-plans').on('click', function () {
-    let params = {
-      plan: Nitrate.Utils.formSerialize(this.form).plan
-    };
-    postToURL(jQ(this).data('param'), params, 'get');
-  });
-  jQ('.js-export-plans').on('click', function () {
-    let params = {
-      plan: Nitrate.Utils.formSerialize(this.form).plan
-    };
-    postToURL(jQ(this).data('param'), params, 'get');
-  });
-  jQ('.js-printable-plans').on('click', function () {
-    let params = {
-      plan: Nitrate.Utils.formSerialize(this.form).plan
-    };
-    postToURL(jQ(this).data('param'), params, 'get');
+  jQ('.js-clone-plans, .js-export-plans, .js-printable-plans').on('click', function () {
+    let params = {plan: Nitrate.Utils.formSerialize(this.form).plan};
+    postToURL(this.dataset.actionUrl, params, 'get');
   });
 }
 
@@ -654,13 +640,10 @@ Nitrate.TestPlans.Details = {
     Nitrate.TestPlans.Runs.initializeRunTab();
     Nitrate.TestPlans.Runs.bind();
 
-    jQ('#btn_edit').on('click', function () {
-      window.location.href = jQ(this).data('param');
-    });
-    jQ('#btn_clone, #btn_export, #btn_print').on('click', function () {
-      let params = jQ(this).data('params');
-      window.location.href = params[0] + '?plan=' + params[1];
+    jQ('#btn_edit, #btn_clone, #btn_export, #btn_print').on('click', function () {
+      window.location.assign(this.dataset.actionUrl);
     });
+
     jQ('#id_import_case_zone').find('.js-close-zone').on('click', function () {
       jQ('#id_import_case_zone').hide();
       jQ('#import-error').empty();
@@ -1185,8 +1168,7 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
       });
 
       navForm.find('.js-new-case').on('click', function () {
-        let params = jQ(this).data('params');
-        window.location.href = params[0] + '?from_plan=' + params[1];
+        window.location.assign(this.dataset.actionUrl);
       });
 
       navForm.find('.js-import-cases').on('click', function () {
@@ -1194,20 +1176,19 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
       });
 
       navForm.find('.js-add-case-to-plan').on('click', function () {
-        window.location.href = jQ(this).data('param');
+        window.location.assign(this.dataset.actionUrl);
       });
 
-      navForm.find('.js-export-cases').on('click', function () {
-        submitSelectedCaseIDs(jQ(this).data('param'), casesTable);
-      });
-
-      navForm.find('.js-print-cases').on('click', function () {
-        submitSelectedCaseIDs(jQ(this).data('param'), casesTable);
+      navForm.find('.js-export-cases, .js-print-cases').on('click', function () {
+        submitSelectedCaseIDs(this.dataset.actionUrl, casesTable);
       });
 
       navForm.find('.js-clone-cases').on('click', function () {
-        let params = {from_plan: planId, case: getSelectedCaseIDs(casesTable)};
-        postToURL(jQ(this).data('param'), params, 'get');
+        let params = {
+          from_plan: planId,
+          case: getSelectedCaseIDs(casesTable)
+        };
+        postToURL(this.dataset.actionUrl, params, 'get');
       });
 
       navForm.find('.js-remove-cases').on('click', function () {
@@ -1223,15 +1204,16 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
       });
 
       navForm.find('.js-new-run').on('click', function () {
-        postToURL(jQ(this).data('param'), {
+        let params = {
           from_plan: planId,
           case: getSelectedCaseIDs(casesTable)
-        });
+        };
+        postToURL(this.dataset.actionUrl, params);
       });
 
       navForm.find('.js-add-case-to-run').on('click', function () {
         let params = {case: getSelectedCaseIDs(casesTable)};
-        postToURL(jQ(this).data('param'), params, 'get');
+        postToURL(this.dataset.actionUrl, params, 'get');
       });
 
       navForm.find('.js-status-item').on('click', function () {
@@ -1241,7 +1223,7 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
           return false;
         }
 
-        let newStatusId = parseInt(jQ(this).data('param'));
+        let newStatusId = parseInt(this.dataset.statusId);
         confirmDialog({
           message: defaultMessages.confirm.change_case_status,
           title: 'Manage Test Case Status',
@@ -1276,7 +1258,7 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
           return false;
         }
 
-        let newValue = jQ(this).data('param');
+        let newValue = this.dataset.priorityId;
 
         confirmDialog({
           message: defaultMessages.confirm.change_case_priority,
@@ -1310,7 +1292,7 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
       if (jQ(casesTable).find('tbody tr:visible').length > 1) {
         // Only make sense to sort rows when there are more than one cases
         jQ(casesTable).find('.js-table-header-sortable').on('click', function () {
-          sortCase(container, jQ(this).parents('thead').data('param'), jQ(this).data('param'));
+          sortCase(container, jQ(this).parents('thead').data('planId'), this.dataset.orderBy);
         });
       }
 
@@ -1461,70 +1443,113 @@ function constructPlanDetailsCasesZone(container, planId, parameters) {
           return false;
         }
 
-        constructBatchTagProcessDialog(planId);
-
-        // Observe the batch tag form submit
-        jQ('#id_batch_tag_form').on('submit', function (e) {
-          e.stopPropagation();
-          e.preventDefault();
-
-          let tagData = Nitrate.Utils.formSerialize(this);
-          if (! tagData.tags) {
-            return false;
-          }
-
-          let params = Object.assign(
-            serializeFormData({
-              'form': navForm[0],
-              'selectedCaseIDs': selectedCaseIDs,
-              'hashable': true
-            }),
-            {
-              tags: tagData.tags, a: 'add', t: 'json', f: 'serialized'
+        let dialog = Nitrate.TestPlans.Details.addTagDialog;
+        if (! dialog) {
+          dialog = jQ('#addTagDialog').dialog({
+            autoOpen: false,
+            resizable: false,
+            modal: true,
+            height: 200,
+            close: function (event, ui) {
+              jQ(this).find('input[type=text]').prop('value', '');
+            },
+            open: function (event, ui) {
+              jQ(this).find('input[type=text]').focus();
+            },
+            buttons: {
+              Add: function () {
+                dialog.find('#addTagForm').trigger('submit');
+                dialog.dialog('close');
+              },
+              Cancel: function () {
+                dialog.dialog('close');
+              }
             }
-          );
+          });
+          Nitrate.TestPlans.Details.addTagDialog = dialog;
 
-          /*
-           * Two reasons to force to remove plan from parameters here.
-           * 1. plan is added in previous cases filter. As the design
-           *    of Show More, previous filter criteria is added for
-           *    selecting all cases with same filter criteria.
-           * 2. existing plan confuses tag view method due to it
-           *    applies to both plan and case to add tag. Thus, the
-           *    existing plan will cause it to add tag to all cases of
-           *    that plan always.
-           *
-           * Placing this line of code is not a good idea. But, it
-           * works well for the current implementation. Possible
-           * solution to avoid this might to split the tag view method
-           * to add tags to plans and cases, respectively. Why to make
-           * change to tag view method? That is, according to the
-           * cases filter implementation, plan must exist in the
-           * filter criteria as a parameter.
-           */
-          delete params.plan;
-
-          sendHTMLRequest({
-            url: '/management/tags/',
-            data: params,
-            traditional: true,
-            success: function (data, textStatus, xhr) {
-              let dialog = getDialog();
-              clearDialog(dialog);
-
-              let template = Handlebars.compile(jQ('#batch_tag_summary_template').html());
-              jQ(dialog)
-                .html(template({'tags': jQ.parseJSON(xhr.responseText)}))
-                .find('.js-close-button')
-                .on('click', function () {
-                  jQ(dialog).hide();
-                })
-                .end().show();
-
-              reloadCases();
+          dialog.find('#add_tag_plan').autocomplete({
+            'minLength': 2,
+            'appendTo': '#id_batch_add_tags_autocomplete',
+            'source': function (request, response) {
+              sendHTMLRequest({
+                url: '/management/getinfo/',
+                data: {
+                  'name__startswith': request.term,
+                  'info_type': 'tags',
+                  'format': 'ulli',
+                  'cases__plan__pk': planId,
+                  'field': 'name'
+                },
+                success: function (data) {
+                  let processedData = [];
+                  if (data.indexOf('<li>') > -1) {
+                    processedData = data
+                      .slice(data.indexOf('<li>') + 4, data.lastIndexOf('</li>'))
+                      .split('<li>')
+                      .join('')
+                      .split('</li>');
+                  }
+                  response(processedData);
+                }
+              });
             },
           });
-        });
+
+          // Observe the batch tag form submit
+          dialog.find('#addTagForm').on('submit', function (e) {
+            e.stopPropagation();
+            e.preventDefault();
+
+            let tagData = Nitrate.Utils.formSerialize(this);
+            if (! tagData.tags) {
+              return false;
+            }
+
+            let params = Object.assign(
+              serializeFormData({
+                'form': navForm[0],
+                'selectedCaseIDs': selectedCaseIDs,
+                'hashable': true
+              }),
+              {
+                tags: tagData.tags, a: 'add', t: 'json', f: 'serialized'
+              }
+            );
+
+            /*
+            * Two reasons to force to remove plan from parameters here.
+            * 1. plan is added in previous cases filter. As the design
+            *    of Show More, previous filter criteria is added for
+            *    selecting all cases with same filter criteria.
+            * 2. existing plan confuses tag view method due to it
+            *    applies to both plan and case to add tag. Thus, the
+            *    existing plan will cause it to add tag to all cases of
+            *    that plan always.
+            *
+            * Placing this line of code is not a good idea. But, it
+            * works well for the current implementation. Possible
+            * solution to avoid this might to split the tag view method
+            * to add tags to plans and cases, respectively. Why to make
+            * change to tag view method? That is, according to the
+            * cases filter implementation, plan must exist in the
+            * filter criteria as a parameter.
+            */
+            delete params.plan;
+
+            sendHTMLRequest({
+              url: '/management/tags/',
+              data: params,
+              traditional: true,
+              success: function (data, textStatus, xhr) {
+                clearDialog(getDialog());
+                reloadCases();
+              },
+            });
+          });
+        }
+
+        dialog.dialog('open');
       });
 
       navForm.find('input.btn_component').on('click', function () {
@@ -1771,43 +1796,6 @@ function renderCategoryForm(container, parameters, formObserve) {
   });
 }
 
-function constructBatchTagProcessDialog(planId) {
-  let template = Handlebars.compile(jQ('#batch_tag_form_template').html());
-  jQ('#dialog').html(template())
-    .find('.js-cancel-button').on('click', function () {
-      jQ('#dialog').hide();
-    })
-    .end().show();
-  // Bind the autocomplete for tags
-  jQ('#add_tag_plan').autocomplete({
-    'minLength': 2,
-    'appendTo': '#id_batch_add_tags_autocomplete',
-    'source': function (request, response) {
-      sendHTMLRequest({
-        url: '/management/getinfo/',
-        data: {
-          'name__startswith': request.term,
-          'info_type': 'tags',
-          'format': 'ulli',
-          'cases__plan__pk': planId,
-          'field': 'name'
-        },
-        success: function (data) {
-          let processedData = [];
-          if (data.indexOf('<li>') > -1) {
-            processedData = data
-              .slice(data.indexOf('<li>') + 4, data.lastIndexOf('</li>'))
-              .split('<li>')
-              .join('')
-              .split('</li>');
-          }
-          response(processedData);
-        }
-      });
-    },
-  });
-}
-
 function sortCase(container, planId, order) {
   let form = jQ(container).children()[0];
   let parameters = Nitrate.Utils.formSerialize(form);
@@ -1901,7 +1889,7 @@ Nitrate.TestPlans.Runs = {
     let that = Nitrate.TestPlans.Runs;
     if (jQ('#tab_testruns').hasClass('tab_focus')) {
       if (!jQ.fn.DataTable.fnIsDataTable(jQ('#testruns_table')[0])) {
-        let url = that.makeUrlFromPlanId(jQ('#testruns_table').data('param'));
+        let url = that.makeUrlFromPlanId(document.getElementById('testruns_table').dataset.planId);
         jQ('#testruns_table').dataTable(
           Object.assign({}, Nitrate.DataTable.commonSettings, {
             sAjaxSource: url,
