@@ -59,10 +59,6 @@ function removeItem(item, caseEstimatedTime) {
   jQ('#' + item).remove();
 }
 
-function cloneRunsClickHandler() {
-  postToURL(jQ(this).data('param'), Nitrate.Utils.formSerialize(this.form), 'get');
-}
-
 
 /**
  * Initialize the test runs search result table and associated action buttons.
@@ -95,7 +91,10 @@ Nitrate.TestRuns.Search.initializeSearchResult = function (searchEndpoint) {
     },
 
     fnInitComplete: function () {
-      jQ('.js-clone-testruns').on('click', cloneRunsClickHandler);
+      jQ('.js-clone-testruns').on('click', function () {
+        let params = Nitrate.Utils.formSerialize(this.form);
+        postToURL(this.dataset.actionUrl, params, 'get');
+      });
     },
 
     fnDrawCallback: function () {
@@ -497,14 +496,22 @@ Nitrate.TestRuns.Details.registerEventHandlersForCaseRunDetail = function (expan
   });
 
   caseRunDetailRow.find('.js-remove-caserun-issue').on('click', function () {
-    let removeIssueInfo = jQ(this).data('params');
-    removeIssueFromCaseRuns(removeIssueInfo, function (data) {
-      let caseRunIssuesCount = data.caserun_issues_count[removeIssueInfo.caseRunIds[0]] || 0;
-      updateIssuesCountInCaseRunRow(expansion.caseRunRow, caseRunIssuesCount);
-      showTheNumberOfCaseRunIssues(data.run_issues_count, removeIssueInfo.runId);
-      expansion.showLoadingAnimation = true;
-      expansion.expand();
-    });
+    let dataset = this.dataset;
+    removeIssueFromCaseRuns(
+      {
+        runId: dataset.runId,
+        caseId: dataset.caseId,
+        caseRunIds: [dataset.caseRunId],
+        issueKey: dataset.issueKey
+      },
+      function (data) {
+        let caseRunIssuesCount = data.caserun_issues_count[dataset.caseRunId] || 0;
+        updateIssuesCountInCaseRunRow(expansion.caseRunRow, caseRunIssuesCount);
+        showTheNumberOfCaseRunIssues(data.run_issues_count, dataset.runId);
+        expansion.showLoadingAnimation = true;
+        expansion.expand();
+      }
+    );
   });
 
   caseRunDetailRow.find('.js-add-testlog').on('click', function () {
@@ -530,10 +537,129 @@ Nitrate.TestRuns.Details.registerEventHandlersForCaseRunDetail = function (expan
   });
 };
 
+function bindRemoveTagHandler() {
+  jQ('.js-remove-tag').on('click', function () {
+    operateTagOnRun(jQ('.js-tag-ul')[0], this.dataset.runId, this.dataset.tag, 'remove');
+  });
+}
+
+function bindEnvPropertyHandlers() {
+  jQ('.js-edit-property').on('click', function () {
+    let dataset = this.dataset
+      , formName = 'id_form_value_' + dataset.runEnvValueId
+      , theEnvForm = document.forms[formName]
+      , envPropertyId = theEnvForm.env_property_id.value
+      ;
+
+    document.getElementById(dataset.envValueElemId).style.display = 'none';
+    document.getElementById(dataset.submitValueElemId).style.display = '';
+
+    let selectValueElem = document.getElementById(dataset.selectValueElemId);
+    selectValueElem.style.display = '';
+
+    getRequest({
+      url: dataset.actionUrl,
+      data: {info_type: 'env_values', env_property_id: envPropertyId},
+      errorMessage: 'Update values failed',
+      success: function (data) {
+        let currentValue = theEnvForm.current_run_env.value;
+        let excludeValues = [];
+
+        for (let i = 0; i < document.forms.length; i++) {
+          let form = document.forms[i];
+          if (form.current_run_env && form.current_run_env.value !== currentValue) {
+            excludeValues.push(window.parseInt(form.current_run_env.value));
+          }
+        }
+
+        let values = [];
+
+        for (let i = 0; i < data.length; i++) {
+          let envValue = data[i];
+          if (excludeValues.indexOf(envValue.pk) < 0) {
+            values.push([envValue.pk, envValue.fields.value]);
+          }
+        }
+
+        setUpChoices(selectValueElem, values, false);
+      },
+    });
+  });
+
+  jQ('.js-remove-property').on('click', function () {
+    let self = this;
+    confirmDialog({
+      message: 'Are you sure to remove this property?',
+      title: 'Manage Test Run\'s Environment',
+      yesFunc: function () {
+        let parent = jQ(self).closest('form');
+        let emptySelf = jQ(self).closest('li');
+        let envValueId = jQ('input[type=hidden][name=current_run_env]', parent).get(0).value;
+
+        postRequest({
+          url: self.dataset.actionUrl,  // '/runs/env_value/delete/',
+          data: {env_value: envValueId, runs: self.dataset.runId},
+          errorMessage: 'Deleting value failed',
+          success: function () { emptySelf.remove(); },
+        });
+      }
+    });
+  });
+
+  jQ('.js-env-submit').on('click', function () {
+    let dataset = this.dataset
+      , selectField = jQ(this).prev()[0];
+
+    let newValue = selectField.options[selectField.selectedIndex].innerHTML;
+    let oldValue = jQ(selectField).prev().prev().val();
+
+    let dupValues = [];
+    jQ('input[type=hidden][name=current_run_env]').each(function (index, element) {
+      if (element.value !== oldValue) {
+        dupValues.push(element.value);
+      }
+      return true;
+    });
+    if (jQ.inArray(selectField.value, dupValues) >= 0) {
+      showModal('The value is exist for this run');
+      return false;
+    }
+
+    postRequest({
+      url: dataset.actionUrl,
+      data: {
+        old_env_value: oldValue,
+        new_env_value: selectField.value,
+        runs: dataset.runId
+      },
+      success: function () {
+        jQ('#' + dataset.envValueElemId).html(newValue).show();
+        jQ(selectField).hide();
+        jQ('#' + dataset.submitValueElemId).hide();
+        jQ(selectField).prev().prev().val(selectField.value);
+      },
+    });
+  });
+}
+
+function bindRemoveCCHandler() {
+  jQ('.js-remove-cc').on('click', function () {
+    let self = this;
+    confirmDialog({
+      message: 'Are you sure to delete this user from CC?',
+      yesFunc: function () {
+        constructRunCC(self.dataset.actionUrl, jQ('.js-cc-ul')[0], self.dataset.runId, {
+          'do': 'remove',
+          'user': self.dataset.userName
+        });
+      }
+    });
+  });
+}
+
 Nitrate.TestRuns.Details.on_load = function () {
   jQ('.js-add-property').on('click', function () {
-    let params = jQ(this).data('params');
-    new AddEnvPropertyDialog(params[0], params[1]).open();
+    new AddEnvPropertyDialog(this.dataset.runId, this.dataset.envGroupId).open();
   });
 
   // Observe the interface buttons
@@ -602,77 +728,34 @@ Nitrate.TestRuns.Details.on_load = function () {
     });
   }
 
-  //bind click to status btn
-  jQ('.btn_status').on('click', function () {
-    let from = jQ(this).siblings('.btn_status:disabled')[0].title;
-    let to = this.title;
-    if (jQ('span#' + to + ' a').text() === '0') {
-      let htmlstr =
-        '[<a href="javascript:void(0)" ' +
-        'onclick="showCaseRunsWithSelectedStatus(jQ(\'#id_filter\')[0], ' + jQ(this).prop('crs_id') + ')">0</a>]';
-      jQ('span#' + to).html(htmlstr);
+  jQ('#btn_edit, #btnDeleteRun, .js-set-run-status').on('click', function () {
+    window.location.assign(this.dataset.actionUrl);
+  });
+
+  jQ('#btn_clone, .js-update-case').on('click', function () {
+    let caseRunIds = getSelectedCaseRunIDs();
+    if (caseRunIds.length === 0) {
+      return;
     }
-    if (jQ('span#' + from + ' a').text() === '1') {
-      jQ('span#' + from).html('[<a>1</a>]');
-    }
-    jQ('span#' + to + ' a').text(window.parseInt(jQ('span#' + to + ' a').text()) + 1);
-    jQ('span#' + from + ' a').text(window.parseInt(jQ('span#' + from + ' a').text()) - 1);
-
-    let caseRunCount = window.parseInt(jQ('span#TOTAL').next().text()) || 0;
-    let passedCaseRunCount = window.parseInt(jQ('span#PASSED a').text()) || 0;
-    let errorCaseRunCount = window.parseInt(jQ('span#ERROR a').text()) || 0;
-    let failedCaseRunCount = window.parseInt(jQ('span#FAILED a').text()) || 0;
-    let waivedCaseRunCount = window.parseInt(jQ('span#WAIVED a').text()) || 0;
-
-    let completedCasesCount = passedCaseRunCount + errorCaseRunCount + failedCaseRunCount + waivedCaseRunCount;
-    let completePercent = 100 * (completedCasesCount / caseRunCount).toFixed(2);
-    let unsuccessfulCasesCount = errorCaseRunCount + failedCaseRunCount;
-    let failedPercent = 100 * (unsuccessfulCasesCount / completedCasesCount).toFixed(2);
-
-    jQ('span#complete_percent').text(completePercent);
-    jQ('div.progress-inner').prop('style', 'width:' + completePercent + '%');
-    jQ('div.progress-failed').prop('style', 'width:' + failedPercent + '%');
+    postToURL(this.dataset.actionUrl, {case_run: caseRunIds});
   });
 
-  jQ('#btn_edit').on('click', function () {
-    let params = jQ(this).data('params');
-    window.location.href = params[0] + '?from_plan=' + params[1];
-  });
-  jQ('#btn_clone').on('click', function () {
-    postToURL(jQ(this).data('param'), {
-      case_run: getSelectedCaseRunIDs()
-    });
-  });
-  jQ('#btn_delete').on('click', function () {
-    window.location.href = jQ(this).data('param');
-  });
-  jQ('#btn_export_csv').on('click', function () {
-    window.location.href = jQ(this).data('param') + '?format=csv&' + jQ('#id_form_case_runs').serialize();
-  });
-  jQ('#btn_export_xml').on('click', function () {
-    window.location.href = jQ(this).data('param') + '?format=xml&' + jQ('#id_form_case_runs').serialize();
-  });
-  jQ('.js-remove-tag').on('click', function () {
-    let params = jQ(this).data('params');
-    removeRuntag(jQ('.js-tag-ul')[0], params[0], params[1]);
+  jQ('#btn_export_csv, #btn_export_xml').on('click', function () {
+    let url = this.dataset.actionUrl + '&' + jQ('input[name=case_run]').serialize();
+    window.location.assign(url);
   });
+
+  bindRemoveTagHandler();
   jQ('.js-add-tag').on('click', function () {
-    addRunTag(jQ('.js-tag-ul')[0], jQ(this).data('param'));
-  });
-  jQ('.js-set-running').on('click', function () {
-    window.location.href = jQ(this).data('param') + '?finished=0';
-  });
-  jQ('.js-set-finished').on('click', function () {
-    window.location.href = jQ(this).data('param') + '?finished=1';
+    let tag = window.prompt('Please type new tag.');
+    if (tag.length > 0) {
+      operateTagOnRun(jQ('.js-tag-ul')[0], this.dataset.runId, tag, 'add');
+    }
   });
+
   jQ('.js-del-case').on('click', function () {
     delCaseRun();
   });
-  jQ('.js-update-case').on('click', function () {
-    postToURL(jQ(this).data('param'), {
-      case_run: getSelectedCaseRunIDs()
-    });
-  });
   jQ('.js-change-assignee').on('click', function () {
     changeCaseRunAssignee();
   });
@@ -681,33 +764,26 @@ Nitrate.TestRuns.Details.on_load = function () {
   jQ('.js-show-commentdialog').on('click', function () {
     showCommentForm();
   });
+
   jQ('.js-add-cc').on('click', function () {
-    addRunCC(jQ(this).data('param'), jQ('.js-cc-ul')[0]);
+    let user = window.prompt('Please type new email or username for CC.').trim();
+    if (user) {
+      constructRunCC(this.dataset.actionUrl, jQ('.js-cc-ul')[0], this.dataset.runId, {'do': 'add', 'user': user});
+    }
   });
-  jQ('.js-remove-cc').on('click', function () {
-    let params = jQ(this).data('params');
-    removeRunCC(params[0], params[1], jQ('.js-cc-ul')[0]);
+  bindRemoveCCHandler();
+
+  bindEnvPropertyHandlers();
+
+  jQ('.js-caserun-total, .js-status-subtotal').on('click', function () {
+    let form = document.forms['filterCaseRunsForm'];
+    form.case_run_status__name.value = this.dataset.statusName;
+    form.submit();
   });
-  jQ('.js-edit-property').on('click', function () {
-    let params = jQ(this).data('params');
-    editValue(jQ(this).parents('form.js-run-env')[0], params[0], params[1], params[2]);
-  });
-  jQ('.js-remove-property').on('click', function () {
-    removeProperty(jQ(this).data('param'), this);
-  });
-  jQ('.js-env-submit').on('click', function () {
-    let params = jQ(this).data('params');
-    submitValue(params[0], params[1], params[2], jQ(this).prev()[0], params[3]);
-  });
-  jQ('.js-caserun-total').on('click', function () {
-    showCaseRunsWithSelectedStatus(jQ('#id_filter')[0], '');
-  });
-  jQ('.js-status-subtotal').on('click', function () {
-    showCaseRunsWithSelectedStatus(jQ('#id_filter')[0], jQ(this).data('param'));
-  });
-  jQ('.js-change-order').on('click', function () {
-    let params = jQ(this).data('params');
-    changeCaseRunOrder(params[0], params[1], params[2]);
+
+  jQ('.js-change-order').on('click', function (e) {
+    changeCaseRunOrder(this.dataset.runId, this.dataset.caseRunId, this.dataset.sortKey);
+    return false;
   });
 };
 
@@ -737,8 +813,7 @@ Nitrate.TestRuns.New.on_load = function () {
   });
   jQ('img.blind_icon').on('click', caseDetailExpansionHandler);
   jQ('.js-remove-case').on('click', function () {
-    let params = jQ(this).data('params');
-    removeItem(params[0], params[1]);
+    removeItem(this.dataset.itemId, window.parseInt(this.dataset.estimatedTime));
   });
 };
 
@@ -1042,93 +1117,6 @@ function delCaseRun() {
   });
 }
 
-function editValue(form, hidebox, selectid, submitid) {
-  jQ('#' + hidebox).hide();
-  jQ('#' + selectid).show();
-  jQ('#' + submitid).show();
-
-  let data = Nitrate.Utils.formSerialize(form);
-  let envPropertyId = data.env_property_id;
-
-  getRequest({
-    url: '/management/getinfo/',
-    data: {info_type: 'env_values', env_property_id: envPropertyId},
-    errorMessage: 'Update values failed',
-    success: function (data) {
-      let currentValue = jQ('input[type=hidden][name=current_run_env]:eq(0)', form);
-      let excludeValues = [];
-
-      jQ('input[type=hidden][name=current_run_env]').each(function (index, element) {
-        if (element.value !== currentValue.val()) {
-          excludeValues.push(window.parseInt(element.value));
-        }
-        return true;
-      });
-
-      let values = [];
-      jQ.each(data, function (index, value) {
-        if (jQ.inArray(value.pk, excludeValues) < 0) {
-          values.push([value.pk, value.fields.value]);
-        }
-        return true;
-      });
-
-      setUpChoices(jQ('#' + selectid)[0], values, false);
-    },
-  });
-}
-
-function submitValue(runId, value, hidebox, selectField, submitid) {
-  let newValue = selectField.options[selectField.selectedIndex].innerHTML;
-  let oldValue = jQ(selectField).prev().prev().val();
-
-  let dupValues = [];
-  jQ('input[type=hidden][name=current_run_env]').each(function (index, element) {
-    if (element.value !== oldValue) {
-      dupValues.push(element.value);
-    }
-    return true;
-  });
-  if (jQ.inArray(selectField.value, dupValues) >= 0) {
-    showModal('The value is exist for this run');
-    return false;
-  }
-
-  postRequest({
-    url: '/runs/env_value/change/',
-    data: {
-      old_env_value: oldValue,
-      new_env_value: selectField.value,
-      runs: runId
-    },
-    success: function () {
-      jQ('#' + hidebox).html(newValue).show();
-      jQ(selectField).hide();
-      jQ('#' + submitid).hide();
-      jQ(selectField).prev().prev().val(selectField.value);
-    },
-  });
-}
-
-function removeProperty(runId, element) {
-  confirmDialog({
-    message: 'Are you sure to remove this porperty?',
-    title: 'Manage Test Run\'s Environment',
-    yesFunc: function () {
-      let parent = jQ(element).closest('form');
-      let emptySelf = jQ(element).closest('li');
-      let envValueId = jQ('input[type=hidden][name=current_run_env]', parent).get(0).value;
-
-      postRequest({
-        url: '/runs/env_value/delete/',
-        data: {env_value: envValueId, runs: runId},
-        errorMessage: 'Deleting value failed',
-        success: function () { emptySelf.remove(); },
-      });
-    }
-  });
-}
-
 function addPropertyToEnv(runId, envValueId) {
   postRequest({
     url: '/runs/env_value/add/',
@@ -1136,66 +1124,37 @@ function addPropertyToEnv(runId, envValueId) {
     success: function (data) {
       jQ('#dialog').hide();
       jQ('#env_area').html(data.fragment);
-      jQ('.js-edit-property').on('click', function () {
-        let params = jQ(this).data('params');
-        editValue(jQ(this).parents('form.js-run-env')[0], params[0], params[1], params[2]);
-      });
-      jQ('.js-remove-property').on('click', function () {
-        removeProperty(jQ(this).data('param'), this);
-      });
-      jQ('.js-env-submit').on('click', function () {
-        let params = jQ(this).data('params');
-        submitValue(params[0], params[1], params[2], jQ(this).prev()[0], params[3]);
-      });
+      bindEnvPropertyHandlers();
     },
   });
 }
 
-function addRunTag(container, runId) {
-  let tag = window.prompt('Please type new tag.');
-  if (!tag) {
-    return false;
-  }
-
-  // FIXME: should be a POST request
+/**
+ * Operator tags on a test run.
+ *
+ * @param {HTMLElement} container - the element containing the tag list.
+ * @param {string|number} runId - the run id to update the associated tags.
+ * @param {string} tag - the tag name to operate on.
+ * @param {string} action - the operation, which should be add or remove.
+ */
+function operateTagOnRun(container, runId, tag, action) {
   sendHTMLRequest({
     url: '/management/tags/',
-    data: {a: 'add', run: runId, tags: tag},
+    data: {a: action, run: runId, tags: tag},
     container: container,
     callbackAfterFillIn: function () {
-      jQ('.js-remove-tag').on('click', function () {
-        let params = jQ(this).data('params');
-        removeRuntag(jQ('.js-tag-ul')[0], params[0], params[1]);
-      });
+      bindRemoveTagHandler();
     }
   });
 }
 
-function removeRuntag(container, runId, tag) {
-  // FIXME: should be a POST request
+function constructRunCC(url, container, runId, parameters) {
   sendHTMLRequest({
-    url: '/management/tags/',
-    data: {a: 'remove', run: runId, tags: tag},
-    container: container,
-    callbackAfterFillIn: function () {
-      jQ('.js-remove-tag').on('click', function () {
-        let params = jQ(this).data('params');
-        removeRuntag(jQ('.js-tag-ul')[0], params[0], params[1]);
-      });
-    }
-  });
-}
-
-function constructRunCC(container, runId, parameters) {
-  sendHTMLRequest({
-    url: '/run/' + runId + '/cc/',
+    url: url,
     data: parameters,
     container: container,
     callbackAfterFillIn: function () {
-      jQ('.js-remove-cc').on('click', function () {
-        let params = jQ(this).data('params');
-        removeRunCC(params[0], params[1], jQ('.js-cc-ul')[0]);
-      });
+      bindRemoveCCHandler();
       if (jQ('#message').length) {
         showModal(jQ('#message').html());
         return false;
@@ -1204,23 +1163,6 @@ function constructRunCC(container, runId, parameters) {
   });
 }
 
-function addRunCC(runId, container) {
-  let user = window.prompt('Please type new email or username for CC.');
-  if (!user) {
-    return false;
-  }
-  constructRunCC(container, runId, {'do': 'add', 'user': user});
-}
-
-function removeRunCC(runId, user, container) {
-  confirmDialog({
-    message: 'Are you sure to delete this user from CC?',
-    yesFunc: function () {
-      constructRunCC(container, runId, {'do': 'remove', 'user': user});
-    }
-  });
-}
-
 function changeCaseRunAssignee() {
   let selectedCaseRunIDs = getSelectedCaseRunIDs();
   if (!selectedCaseRunIDs.length) {
@@ -1276,11 +1218,6 @@ function getSelectedCaseRunIDs() {
   return result;
 }
 
-function showCaseRunsWithSelectedStatus(form, statusName) {
-  form.case_run_status__name.value = statusName;
-  form.submit();
-}
-
 //Added for choose runs and add cases to those runs
 function serializeRunsFromInputList(table) {
   let elements = jQ('#' + table).parent().find('input[name="run"]:checked');
