@@ -7,31 +7,30 @@ import json
 import urllib
 
 from operator import add, itemgetter
+from typing import List, Set
 
 from django.utils.decorators import method_decorator
 from django.conf import settings
-from django.contrib.auth.decorators import permission_required
+from django.contrib.auth.decorators import permission_required, login_required
 from django.contrib.auth.mixins import PermissionRequiredMixin
 from django.core.exceptions import ObjectDoesNotExist
 from django.urls import reverse
-from django.http import Http404, HttpResponsePermanentRedirect
+from django.http import Http404, HttpResponsePermanentRedirect, HttpRequest
 from django.http import HttpResponse, HttpResponseRedirect
 from django.http import HttpResponseBadRequest, JsonResponse
 from django.shortcuts import get_object_or_404, render
 from django.template.loader import get_template
 from django.views.decorators.csrf import csrf_protect
-from django.views.decorators.http import require_GET
-from django.views.decorators.http import require_http_methods
+from django.views.decorators.http import require_http_methods, require_GET, require_POST
 from django.views.generic import View
 from django.views.generic.base import TemplateView
-from tcms.core.responses import JsonResponseBadRequest
 from uuslug import slugify
 
 from tcms.core.db import SQLExecution
 from tcms.core.models import TCMSLog
-from tcms.core.raw_sql import RawSQL
 from tcms.core.utils import checksum
 from tcms.core.utils import DataTableResult
+from tcms.core.responses import JsonResponseBadRequest, JsonResponseNotFound
 from tcms.core.views import prompt
 from tcms.management.models import TCMSEnvGroup, Component
 from tcms.testcases.data import get_exported_cases_and_related_data
@@ -52,7 +51,6 @@ from tcms.testruns.models import TestRun, TestCaseRun
 
 MODULE_NAME = "testplans"
 
-
 # _____________________________________________________________________________
 # helper functons
 
@@ -141,78 +139,6 @@ class CreateNewPlanView(PermissionRequiredMixin, View):
         )
 
 
-# @require_http_methods(['GET', 'POST'])
-# @permission_required('testplans.add_testplan')
-# def new(request, template_name='plan/new.html'):
-#     """New testplan"""
-#
-#     SUB_MODULE_NAME = "new_plan"
-#
-#     # If the form has been submitted...
-#     if request.method == 'POST':
-#         # A form bound to the POST data
-#         form = NewPlanForm(request.POST, request.FILES)
-#         form.populate(product_id=request.POST.get('product'))
-#
-#         # Process the upload plan document
-#         if form.is_valid():
-#             if form.cleaned_data.get('upload_plan_text'):
-#                 # Set the summary form field to the uploaded text
-#                 form.data['text'] = form.cleaned_data['text']
-#
-#                 # Generate the form
-#                 context_data = {
-#                     'module': MODULE_NAME,
-#                     'sub_module': SUB_MODULE_NAME,
-#                     'form': form,
-#                 }
-#                 return render(request, template_name, context=context_data)
-#
-#         # Process the test plan submit to the form
-#
-#         if form.is_valid():
-#             tp = TestPlan.objects.create(
-#                 product=form.cleaned_data['product'],
-#                 author=request.user,
-#                 owner=request.user,
-#                 product_version=form.cleaned_data['product_version'],
-#                 type=form.cleaned_data['type'],
-#                 name=form.cleaned_data['name'],
-#                 create_date=datetime.datetime.now(),
-#                 extra_link=form.cleaned_data['extra_link'],
-#                 parent=form.cleaned_data['parent'],
-#             )
-#
-#             TestPlanEmailSettings.objects.create(plan=tp)
-#
-#             # Add test plan text
-#             if request.user.has_perm('testplans.add_testplantext'):
-#                 tp.add_text(author=request.user, plan_text=form.cleaned_data['text'])
-#
-#             # Add test plan environment groups
-#             if request.user.has_perm('management.add_tcmsenvplanmap'):
-#                 if request.POST.get('env_group'):
-#                     env_groups = TCMSEnvGroup.objects.filter(
-#                         id__in=request.POST.getlist('env_group')
-#                     )
-#
-#                     for env_group in env_groups:
-#                         tp.add_env_group(env_group=env_group)
-#
-#             return HttpResponseRedirect(
-#                 reverse('plan-get', args=[tp.plan_id])
-#             )
-#     else:
-#         form = NewPlanForm()
-#
-#     context_data = {
-#         'module': MODULE_NAME,
-#         'sub_module': SUB_MODULE_NAME,
-#         'form': form,
-#     }
-#     return render(request, template_name, context=context_data)
-
-
 @require_GET
 @permission_required('testplans.delete_testplan')
 def delete(request, plan_id):
@@ -264,33 +190,13 @@ class SimplePlansFilterView(TemplateView):
             if req_user.is_authenticated and author in (req_user.username, req_user.email):
                 self.SUB_MODULE_NAME = "my_plans"
 
-            plans = (
-                TestPlan
-                .list(search_form.cleaned_data)
-                .select_related('author', 'type', 'product')
+            plans = (TestPlan
+                     .list(search_form.cleaned_data)
+                     .select_related('author', 'type', 'product')
+                     .order_by('-create_date'))
 
-                # We want to get the number of cases and runs, without doing
-                # lots of per-test queries.
-                #
-                # Ideally we would get the case/run counts using m2m field tricks
-                # in the ORM
-                # Unfortunately, Django's select_related only works on ForeignKey
-                # relationships, not on ManyToManyField attributes
-                # See http://code.djangoproject.com/ticket/6432
-
-                # SQLAlchemy can handle this kind of thing in several ways.
-                # Unfortunately we're using Django
-
-                # The cleanest way I can find to get it into one query is to
-                # use QuerySet.extra()
-                # See http://docs.djangoproject.com/en/dev/ref/models/querysets
-                .extra(select={
-                    'cases_count': RawSQL.num_cases,
-                    'runs_count': RawSQL.num_runs,
-                    'children_count': RawSQL.num_plans,
-                })
-
-                .order_by('-create_date')
+            plans = TestPlan.apply_subtotal(
+                plans, cases_count=True, runs_count=True, children_count=True,
             )
 
         return search_form, plans
@@ -947,11 +853,6 @@ class PlanComponentsActionView(View):
         return render(request, self.template_name, context={'test_plan': plan})
 
 
-def tree_view(request):
-    """Whole tree view for plans"""
-    # FIXME:
-
-
 @require_GET
 def printable(request, template_name='plan/printable.html'):
     """Create the printable copy for plan"""
@@ -1000,3 +901,99 @@ def export(request, template_name='case/export.xml'):
     filename = f'tcms-testcases-{timestamp_str}.xml'
     response['Content-Disposition'] = f'attachment; filename={filename}'
     return response
+
+
+@require_GET
+def construct_plans_treeview(request, plan_id):
+    """Construct a plan's tree view"""
+    plan = get_object_or_404(TestPlan, pk=plan_id)
+
+    tree_plan_ids = plan.get_ancestor_ids() + plan.get_descendant_ids()
+    tree_plan_ids.append(plan.pk)
+
+    plans = (TestPlan.objects
+             .filter(pk__in=tree_plan_ids)
+             .only('pk', 'name', 'parent_id')
+             .order_by('parent_id', 'pk'))
+
+    plans = TestPlan.apply_subtotal(
+        plans, cases_count=True, runs_count=True, children_count=True
+    )
+
+    return render(request, 'plan/get_treeview.html', context={
+        'current_plan_id': plan_id,
+        'plans': plans
+    })
+
+
+@login_required
+@require_POST
+def treeview_add_child_plans(request: HttpRequest, plan_id: int):
+    plan = TestPlan.objects.filter(pk=plan_id).only('pk').first()
+    if plan is None:
+        return JsonResponseNotFound({
+            'message': f'Plan {plan_id} does not exist.'
+        })
+
+    child_plan_ids: List[str] = request.POST.getlist('children')
+    child_plans: List[TestPlan] = []
+
+    ancestor_ids = plan.get_ancestor_ids()
+    descendant_ids = plan.get_descendant_ids()
+
+    for child_plan_id in child_plan_ids:
+        if not child_plan_id.isdigit():
+            return JsonResponseBadRequest({
+                'message': f'Child plan id {child_plan_id} is not a number.'
+            })
+        child_plan: TestPlan = (TestPlan.objects
+                                .filter(pk=int(child_plan_id)).only('pk')
+                                .first())
+        if child_plan is None:
+            return JsonResponseBadRequest({
+                'message': f'Child plan {child_plan_id} does not exist.'
+            })
+        if child_plan.pk in ancestor_ids:
+            return JsonResponseBadRequest({
+                'message': f'Plan {child_plan_id} is an ancestor of '
+                           f'plan {plan_id} already.'
+            })
+        if child_plan.pk in descendant_ids:
+            return JsonResponseBadRequest({
+                'message': f'Plan {child_plan_id} is a descendant of '
+                           f'plan {plan_id} already.'
+            })
+
+        child_plans.append(child_plan)
+
+    for child_plan in child_plans:
+        child_plan.parent = plan
+        child_plan.save(update_fields=['parent'])
+
+    return JsonResponse({
+        'parent_plan': plan.pk,
+        'children_plans': [plan.pk for plan in child_plans]
+    })
+
+
+@login_required
+@require_POST
+def treeview_remove_child_plans(request, plan_id: int):
+    plan: TestPlan = TestPlan.objects.filter(pk=plan_id).only('pk').first()
+    if plan is None:
+        return JsonResponseNotFound({
+            'message': f'Plan {plan_id} does not exist.'
+        })
+
+    child_plan_ids: Set[int] = set(map(int, request.POST.getlist('children')))
+    direct_descendants = set(plan.get_descendant_ids(True))
+    ids_to_remove = child_plan_ids & direct_descendants
+
+    if ids_to_remove:
+        TestPlan.objects.filter(pk__in=ids_to_remove).update(parent=None)
+
+    return JsonResponse({
+        'parent_plan': plan.pk,
+        'removed': sorted(ids_to_remove),
+        'non_descendants': sorted(child_plan_ids - direct_descendants),
+    })
