@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-
 from datetime import datetime, timedelta
+from typing import Dict
 
 from django.conf import settings
 from django.contrib.contenttypes.fields import GenericRelation
 from django.urls import reverse
 from django.db import models
-from django.db.models import Q
+from django.db.models import Q, QuerySet
 from django.db.models.signals import post_save, post_delete, pre_save
 from django.db.models import Count
 
@@ -85,7 +85,7 @@ class TestRun(TCMSActionModel):
         return s.serialize_queryset()
 
     @classmethod
-    def list(cls, query):
+    def list(cls, query: Dict) -> QuerySet:
         conditions = []
 
         mapping = {
@@ -257,33 +257,6 @@ class TestRun(TCMSActionModel):
         percent = round(percent, 2)
         return percent
 
-    def _get_completed_case_run_percentage(self):
-        ids = TestCaseRunStatus.completed_status_ids()
-        completed_caserun = self.case_run.filter(
-            case_run_status__in=ids)
-
-        percentage = self.get_percentage(completed_caserun.count())
-        return percentage
-
-    # IIRC, this could be used inside the test runs search result to provide
-    # data for progress bar.
-    completed_case_run_percent = property(_get_completed_case_run_percentage)
-
-    def _get_failed_case_run_num(self):
-        failed_status_id = TestCaseRunStatus.name_to_id('FAILED')
-        failed_caserun = self.case_run.filter(
-            case_run_status=failed_status_id
-        )
-        return failed_caserun.count()
-
-    failed_case_run_num = property(_get_failed_case_run_num)
-
-    def _get_failed_case_run_percentage(self):
-        percentage = self.get_percentage(self.failed_case_run_num)
-        return percentage
-
-    failed_case_run_percent = property(_get_failed_case_run_percentage)
-
     def _get_passed_case_run_num(self):
         passed_status_id = TestCaseRunStatus.name_to_id('PASSED')
         passed_caserun = self.case_run.filter(
@@ -338,6 +311,12 @@ class TestRun(TCMSActionModel):
         ).values('case_run').annotate(issues_count=Count('pk'))
         return {item['case_run']: item['issues_count'] for item in q}
 
+    def get_issue_trackers(self) -> QuerySet:
+        """Get enabled issue trackers in order to add issues to case runs of this run"""
+        return (self.plan.product.issue_trackers
+                .filter(enabled=True)
+                .only('pk', 'name', 'validate_regex'))
+
 
 # FIXME: replace TestCaseRunStatus' internal cache with Django's cache
 # machanism
@@ -348,6 +327,9 @@ class TestCaseRunStatus(EnumLike, TCMSActionModel):
     failure_status_names = ('ERROR', 'FAILED')
     idle_status_names = ('IDLE',)
 
+    _complete_statuses = None
+    _failed_status = None
+
     id = models.AutoField(db_column='case_run_status_id', primary_key=True)
     name = models.CharField(max_length=60, blank=True, unique=True)
     sortkey = models.IntegerField(null=True, blank=True, default=0)
@@ -485,7 +467,7 @@ class TestCaseRun(TCMSActionModel):
     def is_finished(self):
         return self.case_run_status.is_finished()
 
-    def get_issues(self):
+    def get_issues(self) -> QuerySet:
         """Get issues added to this case run
 
         :return: a queryset of the issues.
