@@ -179,6 +179,7 @@ class TestAttachmentFactory(DjangoModelFactory):
     submitter = factory.SubFactory(UserFactory)
     create_date = factory.LazyFunction(datetime.now)
     description = factory.Sequence(lambda n: 'Attachment Image %d' % n)
+    checksum = factory.sequence(lambda n: f'12ac3b{n}')
 
 
 class TestAttachmentDataFactory(DjangoModelFactory):
@@ -260,7 +261,7 @@ class TestPlanFactory(DjangoModelFactory):
     # FIXME: How to create field for field parent
 
     @factory.post_generation
-    def attachment(self, create, extracted, **kwargs):
+    def attachments(self, create, extracted, **kwargs):
         if not create:
             return
         if extracted:
@@ -378,7 +379,7 @@ class TestCaseFactory(DjangoModelFactory):
     reviewer = factory.SubFactory(UserFactory)
 
     @factory.post_generation
-    def attachment(self, create, extracted, **kwargs):
+    def attachments(self, create, extracted, **kwargs):
         if not create:
             return
         if extracted:
@@ -632,6 +633,7 @@ class IssueTrackerProductFactory(DjangoModelFactory):
 class IssueTrackerFactory(DjangoModelFactory):
     """Factory to create model IssueTracker"""
 
+    enabled = True
     name = factory.Sequence(lambda n: f'Cool Issue Tracker {n}')
     issue_url_fmt = 'http://localhost/%{issue_key}s'
     validate_regex = r'^\d+$'
