@@ -7,7 +7,7 @@ from unittest.mock import patch
 from tcms.testplans.helpers import email
 from tcms.testplans.models import _disconnect_signals, TestPlan
 from tcms.testplans.models import _listen
-from tests import factories as f
+from tests import factories as f, BasePlanCase
 
 
 class TestSendEmailOnPlanUpdated(test.TestCase):
@@ -174,3 +174,53 @@ class TestGetPlanNotificationRecipients(test.TestCase):
         email.email_plan_deletion(plan)
 
         mailto.assert_not_called()
+
+
+class TestPlanTreeView(BasePlanCase):
+
+    @classmethod
+    def setUpTestData(cls):
+        super().setUpTestData()
+        cls.create_treeview_data()
+
+    def test_get_ancestor_ids(self):
+        expected = [self.plan.pk, self.plan_2.pk, self.plan_3.pk]
+        plan: TestPlan = TestPlan.objects.get(pk=self.plan_4.pk)
+        self.assertListEqual(expected, sorted(plan.get_ancestor_ids()))
+
+    def test_get_ancestors(self):
+        ancestor_ids = [self.plan.pk, self.plan_2.pk, self.plan_3.pk]
+        expected = [
+            repr(item) for item in
+            TestPlan.objects.filter(pk__in=ancestor_ids).order_by('pk')
+        ]
+        plan: TestPlan = TestPlan.objects.get(pk=self.plan_4.pk)
+        self.assertQuerysetEqual(plan.get_ancestors().order_by('pk'), expected)
+
+    def test_get_descendant_ids(self):
+        expected = [self.plan_4.pk, self.plan_5.pk, self.plan_6.pk, self.plan_7.pk]
+        plan: TestPlan = TestPlan.objects.get(pk=self.plan_3.pk)
+        self.assertListEqual(expected, sorted(plan.get_descendant_ids()))
+
+    def test_get_descendants(self):
+        descendant_ids = [
+            self.plan_4.pk, self.plan_5.pk, self.plan_6.pk, self.plan_7.pk
+        ]
+        expected = [
+            repr(item) for item in
+            TestPlan.objects.filter(pk__in=descendant_ids).order_by('pk')
+        ]
+        plan: TestPlan = TestPlan.objects.get(pk=self.plan_3.pk)
+        self.assertQuerysetEqual(
+            plan.get_descendants().order_by('pk'), expected)
+
+    def test_get_direct_descendants(self):
+        test_data = [
+            [self.plan.pk, [self.plan_2.pk]],
+            [self.plan_5.pk, []],
+            [self.plan_3.pk, [self.plan_4.pk, self.plan_7.pk]],
+        ]
+
+        for parent_plan, expected in test_data:
+            plan: TestPlan = TestPlan.objects.get(pk=parent_plan)
+            self.assertListEqual(expected, sorted(plan.get_descendant_ids(True)))
